/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Text Trix code.
 *
 * The Initial Developer of the Original Code is
 * Text Flex.
 * Portions created by the Initial Developer are Copyright (C) 2003-4
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): David Young <dvd@textflex.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

package com.textflex.texttrix;

import javax.swing.*;
import java.io.*;

/** Plugin to reveal a text document's non-printing characters.
    Such characters include paragraph and tab markers.
    The plugin adds representations for these markers directly into 
    the next, not only for visual display but also as actual characters
    to save.
*/
public class NonPrintingChars extends PlugIn {

	/** Constructs the non-printing-character visualizer with 
	descriptive text and images.
	*/
	public NonPrintingChars() {
		super(
			"Non-Printing Characters",
			"tools",
			"Displays unprinted characters within the text",
			"desc.html",
			"icon.png",
			"icon-roll.png");
	}

	/** Gets the normal icon.
	@return normal icon
	*/
	public ImageIcon getIcon() {
		return getIcon(getIconPath());
	}

	/** Gets the rollover icon.
	@return rollover icon
	*/
	public ImageIcon getRollIcon() {
		return getRollIcon(getRollIconPath());
	}

	/** Gets the detailed, HTML-formatted description.
	For display as a tool tip.
	@return a buffered reader for the description file
	*/
	public BufferedReader getDetailedDescription() {
		return super.getDetailedDescription(getDetailedDescriptionPath());
	}
	
	public PlugInOutcome run(String text) {
		int len = text.length();
		int start = 0;
		int end = len;
		StringBuffer s = new StringBuffer(len);
		char c;

		// append text preceding the selection
		s.append(text.substring(0, start));
		// progress char by char, revealing newlines and tabs explicitly
		for (int i = start; i < end; i++) {
			c = text.charAt(i);
			switch (c) {
				case '\n' :
					s.append("\\n" + c);
					break;
				case '\t' :
					s.append("\\t" + c);
					break;
				default :
					s.append(c);
					break;
			}
		}
		return new PlugInOutcome(s.toString());// + text.substring(end));
	}

}
